@@ -1,3 +1,4 @@
+from typing import Optional
 import os, sys
 from art import text2art
 import inquirer
@@ -5,6 +6,8 @@ from agentstack import conf, log
 from agentstack.conf import ConfigFile
 from agentstack.exceptions import ValidationError
 from agentstack.utils import validator_not_empty, is_snake_case
+from agentstack.generation import InsertionPoint
+from agentstack import repo
 
 
 PREFERRED_MODELS = [
@@ -32,6 +35,25 @@ def welcome_message():
     log.info(border)
 
 
+def undo() -> None:
+    """Undo the last committed changes."""
+    conf.assert_project()
+    
+    changed_files = repo.get_uncommitted_files()
+    if changed_files:
+        log.warning("There are uncommitted changes that may be overwritten.")
+        for changed in changed_files:
+            log.info(f" - {changed}")
+        should_continue = inquirer.confirm(
+            message="Do you want to continue?",
+            default=False,
+        )
+        if not should_continue:
+            return
+
+    repo.revert_last_commit(hard=True)
+
+
 def configure_default_model():
     """Set the default model"""
     agentstack_config = ConfigFile()
@@ -78,3 +100,17 @@ def get_validated_input(
             raise ValidationError("Input must be in snake_case")
         return value
 
+
+def parse_insertion_point(position: Optional[str] = None) -> Optional[InsertionPoint]:
+    """
+    Parse an insertion point CLI argument into an InsertionPoint enum.
+    """
+    if position is None:
+        return None  # defer assumptions
+
+    valid_positions = {x.value for x in InsertionPoint}
+    if position not in valid_positions:
+        raise ValueError(f"Position must be one of {','.join(valid_positions)}.")
+
+    return next(x for x in InsertionPoint if x.value == position)
+
