@@ -1,13 +1,15 @@
 import sys
-from typing import Optional
+from typing import TYPE_CHECKING, Optional
 from agentstack import log
 from agentstack.exceptions import ValidationError
 from agentstack.conf import ConfigFile
-from agentstack.generation import parse_insertion_point
 from agentstack import frameworks
 from agentstack.utils import verify_agentstack_project
 from agentstack.agents import AgentConfig, AGENTS_FILENAME
 
+if TYPE_CHECKING:
+    from agentstack.generation import InsertionPoint
+
 
 def add_agent(
     name: str,
@@ -16,7 +18,7 @@ def add_agent(
     backstory: Optional[str] = None,
     llm: Optional[str] = None,
     allow_delegation: Optional[bool] = None,
-    position: Optional[str] = None,
+    position: Optional['InsertionPoint'] = None,
 ):
     agentstack_config = ConfigFile()
     verify_agentstack_project()
@@ -31,9 +33,8 @@ def add_agent(
         if allow_delegation:
             log.warning("Agent allow_delegation is not implemented.")
 
-    _position = parse_insertion_point(position)
     try:
-        frameworks.add_agent(agent, _position)
+        frameworks.add_agent(agent, position)
     except ValidationError as e:
         raise ValidationError(f"Error adding agent to project:\n{e}")
 
