@@ -1,4 +1,6 @@
+import json
 import os, sys
+from pathlib import Path
 from typing import Optional
 from agentstack import conf, log
 from agentstack.conf import ConfigFile
@@ -47,6 +49,58 @@ def add_tool(name: str, agents: Optional[list[str]] = []):
         log.notify(f'🪩  {tool.cta}')
 
 
+def create_tool(tool_name: str, agents: Optional[list[str]] = []):
+    """Create a new custom tool.
+
+    Args:
+        tool_name: Name of the tool to create (must be snake_case)
+        agents: List of agents to make tool available to
+    """
+
+    # Check if tool already exists
+    user_tools_dir = conf.PATH / "src/tools"
+    tool_path = user_tools_dir / tool_name
+    if tool_path.exists():
+        raise Exception(f"Tool '{tool_name}' already exists.")
+
+    # Create tool directory
+    tool_path.mkdir(parents=True, exist_ok=False)
+
+    # Create __init__.py with basic function template
+    init_file = tool_path / '__init__.py'
+    init_content = f'''
+    
+def {tool_name}_tool(value: str) -> str:
+    """
+    Define your tool's functionality here.
+
+    Args:
+        value: Input to process (should be typed in function definition)
+
+    Returns:
+        str: Result of the tool's operation
+    """ 
+    # Add your tool's logic here
+    return value
+'''
+    init_file.write_text(init_content)
+
+    tool_config = ToolConfig(
+        name=tool_name,
+        category="custom",
+        tools=[f'{tool_name}_tool', ],
+    )
+    tool_config.write_to_file(tool_path / 'config.json')
+
+    # Edit the framework entrypoint file to include the tool in the agent definition
+    if not agents:  # If no agents are specified, add the tool to all agents
+        agents = frameworks.get_agent_method_names()
+    for agent_name in agents:
+        frameworks.add_tool(tool_config, agent_name)
+
+    log.success(f"🔨 Tool '{tool_name}' has been created successfully in {user_tools_dir}.")
+
+
 def remove_tool(name: str, agents: Optional[list[str]] = []):
     agentstack_config = ConfigFile()
 
