@@ -8,13 +8,13 @@ from pathlib import Path
 import importlib.resources
 from agentstack import conf
 from inquirer import errors as inquirer_errors
+from appdirs import user_data_dir
 
 
 def get_version(package: str = 'agentstack'):
     try:
         return version(package)
     except (KeyError, FileNotFoundError) as e:
-        print(e)
         return "Unknown version"
 
 
@@ -22,12 +22,11 @@ def verify_agentstack_project():
     try:
         agentstack_config = conf.ConfigFile()
     except FileNotFoundError:
-        print(
-            "\033[31mAgentStack Error: This does not appear to be an AgentStack project."
-            "\nPlease ensure you're at the root directory of your project and a file named agentstack.json exists. "
-            "If you're starting a new project, run `agentstack init`\033[0m"
+        raise Exception(
+            "This does not appear to be an AgentStack project.\n"
+            "Please ensure you're at the root directory of your project and a file named agentstack.json exists.\n"
+            "If you're starting a new project, run `agentstack init`."
         )
-        sys.exit(1)
 
 
 def get_package_path() -> Path:
@@ -120,3 +119,16 @@ def validator_not_empty(min_length=1):
         return True
 
     return validator
+
+def get_base_dir():
+    """Try to get appropriate directory for storing update file"""
+    try:
+        base_dir = Path(user_data_dir("agentstack", "agency"))
+        # Test if we can write to directory
+        test_file = base_dir / '.test_write_permission'
+        test_file.touch()
+        test_file.unlink()
+    except (RuntimeError, OSError, PermissionError):
+        # In CI or when directory is not writable, use temp directory
+        base_dir = Path(os.getenv('TEMP', '/tmp'))
+    return base_dir
\ No newline at end of file
