@@ -2,27 +2,32 @@ import os, sys
 from pathlib import Path
 import shutil
 import unittest
-from parameterized import parameterized_class
 import ast
 
 from agentstack.conf import ConfigFile, set_path
 from agentstack import frameworks
 from agentstack.exceptions import ValidationError
+from agentstack.agents import AGENTS_FILENAME
+from agentstack.tasks import TASKS_FILENAME
 from agentstack.generation.agent_generation import add_agent
 
 BASE_PATH = Path(__file__).parent
 
 
-@parameterized_class([{"framework": framework} for framework in frameworks.SUPPORTED_FRAMEWORKS])
 class TestGenerationAgent(unittest.TestCase):
     def setUp(self):
-        self.project_dir = BASE_PATH / 'tmp' / 'agent_generation'
+        self.framework = os.getenv('TEST_FRAMEWORK')
+        self.project_dir = BASE_PATH / 'tmp' / self.framework / 'agent_generation'
 
         os.makedirs(self.project_dir)
         os.makedirs(self.project_dir / 'src')
         os.makedirs(self.project_dir / 'src' / 'config')
         (self.project_dir / 'src' / '__init__.py').touch()
 
+        # copy agents.yaml and tasks.yaml
+        shutil.copy(BASE_PATH / 'fixtures/agents_max.yaml', self.project_dir / AGENTS_FILENAME)
+        shutil.copy(BASE_PATH / 'fixtures/tasks_max.yaml', self.project_dir / TASKS_FILENAME)
+
         # set the framework in agentstack.json
         shutil.copy(BASE_PATH / 'fixtures' / 'agentstack.json', self.project_dir / 'agentstack.json')
         set_path(self.project_dir)
@@ -42,7 +47,7 @@ class TestGenerationAgent(unittest.TestCase):
             role='role',
             goal='goal',
             backstory='backstory',
-            llm='llm',
+            llm='openai/gpt-4o',
         )
 
         entrypoint_path = frameworks.get_entrypoint_path(self.framework)
@@ -54,11 +59,11 @@ class TestGenerationAgent(unittest.TestCase):
         ast.parse(entrypoint_src)
 
     def test_add_agent_exists(self):
-        with self.assertRaises(SystemExit) as context:
+        with self.assertRaises(Exception) as context:
             add_agent(
-                'test_agent',
+                'agent_name',
                 role='role',
                 goal='goal',
                 backstory='backstory',
-                llm='llm',
+                llm='openai/gpt-4o',
             )
